"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/index.ts
var src_exports = {};
__export(src_exports, {
  buildDeleteFetcher: () => buildDeleteFetcher,
  buildInsertFetcher: () => buildInsertFetcher,
  buildUpdateFetcher: () => buildUpdateFetcher,
  buildUpsertFetcher: () => buildUpsertFetcher,
  createFetcher: () => createFetcher,
  createPaginationFetcher: () => createPaginationFetcher,
  createPaginationHasMoreFetcher: () => createPaginationHasMoreFetcher
});
module.exports = __toCommonJS(src_exports);

// src/delete.ts
var buildDeleteFetcher = (qb, primaryKeys, query) => (input) => __async(void 0, null, function* () {
  let filterBuilder = qb.delete();
  for (const key of primaryKeys) {
    const value = input[key];
    if (!value)
      throw new Error(`Missing value for primary key ${String(key)}`);
    filterBuilder = filterBuilder.eq(key, value);
  }
  const { data } = yield filterBuilder.select(query != null ? query : "*").throwOnError().single();
  return data;
});

// src/fetcher.ts
function createFetcher(mode) {
  return (query) => __async(this, null, function* () {
    if (mode === "single") {
      const { data: data2 } = yield query.throwOnError().single();
      return { data: data2 };
    }
    if (mode === "maybeSingle") {
      const { data: data2 } = yield query.throwOnError().maybeSingle();
      return { data: data2 };
    }
    const { data, count } = yield query.throwOnError();
    return { data, count };
  });
}

// src/insert.ts
var buildInsertFetcher = (qb, mode, query) => (input) => __async(void 0, null, function* () {
  if (!Array.isArray(input))
    input = [input];
  const filterBuilder = qb.insert(input).throwOnError().select(query != null ? query : "*");
  if (mode === "single") {
    const { data } = yield filterBuilder.single();
    return data;
  } else {
    const { data } = yield filterBuilder;
    return data;
  }
});

// src/pagination-fetcher.ts
var createPaginationFetcher = (query, decode, pageSize) => {
  if (!query)
    return null;
  return (...args) => __async(void 0, null, function* () {
    var _a, _b;
    const decodedKey = decode(...args);
    const limit = ((_a = decodedKey.limit) != null ? _a : pageSize) - 1;
    const offset = (_b = decodedKey.offset) != null ? _b : 0;
    const { data } = yield query.range(offset, offset + limit).throwOnError();
    return data;
  });
};
var createPaginationHasMoreFetcher = (query, decode, pageSize) => {
  if (!query)
    return null;
  return (...args) => __async(void 0, null, function* () {
    var _a, _b;
    const decodedKey = decode(...args);
    const limit = (_a = decodedKey.limit) != null ? _a : pageSize;
    const offset = (_b = decodedKey.offset) != null ? _b : 0;
    const result = yield query.range(offset, offset + limit).throwOnError();
    const data = result.data;
    if (data && data.length === pageSize + 1) {
      data[data.length - 1] = { hasMore: true };
    }
    return data;
  });
};

// src/update.ts
var buildUpdateFetcher = (qb, primaryKeys, query) => (input) => __async(void 0, null, function* () {
  let filterBuilder = qb.update(input);
  for (const key of primaryKeys) {
    const value = input[key];
    if (!value)
      throw new Error(`Missing value for primary key ${String(key)}`);
    filterBuilder = filterBuilder.eq(key, value);
  }
  const { data } = yield filterBuilder.select(query != null ? query : "*").throwOnError().single();
  return data;
});

// src/upsert.ts
var buildUpsertFetcher = (qb, mode, query) => (input) => __async(void 0, null, function* () {
  if (!Array.isArray(input))
    input = [input];
  const filterBuilder = qb.upsert(input).throwOnError().select(query != null ? query : "*");
  if (mode === "single") {
    const { data } = yield filterBuilder.single();
    return data;
  } else {
    const { data } = yield filterBuilder;
    return data;
  }
});
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  buildDeleteFetcher,
  buildInsertFetcher,
  buildUpdateFetcher,
  buildUpsertFetcher,
  createFetcher,
  createPaginationFetcher,
  createPaginationHasMoreFetcher
});
//# sourceMappingURL=index.js.map